<?php
/**
 * Title: Responsive Custom Header Image
 * Description: Webdesigner Depot tutorial - example code
 * Author: Anna Ladoshkina
 * Author URI: http://www.foralien.com
 *
 * How to use:
 * 
 * 1. Paste the code in your theme's function.php file
 * 2. Put images in appropriate folder with your theme
 * 3. Correct URLs of images to point to the correct folder
 * 4. Paste the following code into your theme header.php - where the image should be
 *    <?php frl_header_image_markup(); ?>
 *    
 **/
   

/**
 * Add custom image support
 **/
$default_url = get_template_directory_uri().'/_inc/img/city-large.jpg'; //state your own URL
$args = array(
	'default-image'          => $default_url,
	'random-default'         => false,		
	'width'                  => 1000,
	'height'                 => 300,
	'flex-height'            => true,
	'flex-width'             => true,	
	'header-text'            => false,
	'default-text-color'     => '',
	'uploads'                => true,
	'wp-head-callback'       => 'frl_header_image_style',
	'admin-head-callback'    => 'frl_admin_header_image_style',
    'admin-preview-callback' => 'frl_admin_header_image_markup',
);
add_theme_support('custom-header', $args);


/**
 * Register default image's options
 **/
register_default_headers(array(
    'city' => array(
        'url' => '%s/_inc/img/city-large.jpg', //state your own URL
        'thumbnail_url' => '%s/_inc/img/city-thumb.jpg', //state your own URL
        'description' => 'City'
    ),
    'forest' => array(
        'url' => '%s/_inc/img/forest-large.jpg', //state your own URL
        'thumbnail_url' => '%s/_inc/img/forest-thumb.jpg', //state your own URL
        'description' => 'Forest'
    )  
));


/**
 * Register additional sizes
 **/
add_image_size('header_medium', 600, 900, false);
add_image_size('header_minimal', 430, 900, false);


/**
 * Responsive header markup for frontend
 *
 * the markup use <noscript> responsive image techique as Antti Peisa describes it
 * @link http://www.monoliitti.com/images/
 *
 * with a slight alternation required by jQuery Picture plugin
 * @link http://jquerypicture.com/ 
 **/
function frl_header_image_markup(){
	
    /* get full-size image */
    $custom_header = get_custom_header();
    $large = esc_url($custom_header->url);
	$mininal = $medium = '';
        
    /* get smaller sizes of image */
    if(isset($custom_header->attachment_id)){ //uploaded image
        $medium_src = wp_get_attachment_image_src(intval($custom_header->attachment_id), 'header_medium', false);
        if(isset($medium_src[0]))
            $medium = esc_url($medium_src[0]);
		
		$minimal_src = wp_get_attachment_image_src(intval($custom_header->attachment_id), 'header_minimal', false);
		if(isset($minimal_src[0]))
            $mininal = esc_url($minimal_src[0]);
        
    } else { //default image
        $medium = esc_url(str_replace('-large', '-small', $custom_header->url));
		$mininal = esc_url(str_replace('-large', '-thumb', $custom_header->url));
    }
	
	/* fallback for some unexpected errors */
   if(empty($medium))
		$medium = $large;
	
	if(empty($mininal))
		$mininal = $large;
		
?>
<figure id="header-image" data-media="<?php echo $mininal;?>" data-media440="<?php echo $medium;?>" data-media600="<?php echo $large;?>">
    <noscript>
        <img src="<?php echo $large;?>">
    </noscript>
</figure>
<?php
}


/**
 * CSS for responsive header in frontend
 **/
function frl_header_image_style() {
	
	$src = get_template_directory_uri().'/_inc/js/jquery-picture-min.js';
    wp_enqueue_script('jquery-picture', $src, array('jquery'), 0.9, true);
?>
	<style type="text/css">
        #header-image {
            padding: 0.5em 0; }
            
        #header-image img {
			vertical-align: bottom;
            width: 100%;
            height: auto; }
    </style>
	
	<script>
        jQuery(document).ready(function($){
            $('#header-image').picture();
        });
    </script>
<?php
}


/**
 * Header preview in admin
 * in admin will display fullsized image
 **/
function frl_admin_header_image_markup() {
	
	$image = get_header_image();
?>
	<div id="header-image">
	<?php if($image): ?>
		<img src="<?php echo esc_url($image); ?>" alt="" />
	<?php endif; ?>
	</div>
<?php
}

function frl_admin_header_image_style() {	
?>	
	<style>
		#header-image {
			max-width: 1000px;
			max-height: 400px; }
		
		#header-image img {
			vertical-align: bottom;
			width: 100%;
			height: auto; }
	</style>
<?php	
}


?>